
# Slot: negatively regulates




URI: [biolink:negatively_regulates](https://w3id.org/biolink/vocab/negatively_regulates)


## Domain and Range

[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md) &#8594;  <sub>0..1</sub> [PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)

## Parents

 *  is_a: [regulates](regulates.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | This is a grouping for negative process-process and entity-entity regulation. |
| **Exact Mappings:** | | RO:0004035 |
|  | | RO:0002212 |
| **Close Mappings:** | | RO:0002335 |
| **Narrow Mappings:** | | CHEMBL.MECHANISM:blocker |
|  | | CHEMBL.MECHANISM:inhibitor |
|  | | CHEMBL.MECHANISM:negative_allosteric_modulator |
|  | | CHEMBL.MECHANISM:negative_modulator |
|  | | RO:0002630 |
| **Broad Mappings:** | | RO:0004033 |

